@@ -4,9 +4,13 @@ options(width = 1000)
 ## ---- echo = FALSE, message=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(IncDTW)
 library(dtw)
-benchmark_replications <- c(100,100)
+#TODO add new functions DBA
+#TODO add new function dtw_dismat
+#TODO add new function dtw_disvec
+
 # if(require(microbenchmark)){}
 
+
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 set.seed(1090)
 Q <- sin(1:10)#+rnorm(20)
@@ -15,10 +19,10 @@ tmp <- IncDTW::dtw(Q = Q, C = C, return_diffM = TRUE, return_wp = TRUE,
                    return_QC = TRUE, return_cm = TRUE, return_diffp = TRUE)
 names(tmp)
 
-## ---- fig.show=TRUE, results='hide', fig.align='center', fig.height=3.5, fig.width=7, echo=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- fig.show=TRUE, results='hide', fig.align='center', fig.height=2, fig.width=7, echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 plot(x=tmp, type = "QC")
 
-## ---- fig.show=TRUE, results='hide', fig.align='center', fig.height=7, fig.width=7, echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- fig.show=TRUE, results='hide', fig.align='center', fig.height=5, fig.width=7, echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 plot(x=tmp, type = "warp")
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -30,10 +34,10 @@ tmp <- IncDTW::dtw(Q = Q, C = C, return_diffM = TRUE, return_wp = TRUE,
                    return_QC = TRUE, return_cm = TRUE, return_diffp = TRUE)
 names(tmp)
 
-## ---- fig.show=TRUE, results='hide', fig.align='center', fig.height=3.5, fig.width=7, echo=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- fig.show=TRUE, results='hide', fig.align='center', fig.height=2, fig.width=7, echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 plot(x=tmp, type = "QC")
 
-## ---- fig.show=TRUE, results='hide', fig.align='center', fig.height=7, fig.width=7, echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ---- fig.show=TRUE, results='hide', fig.align='center', fig.height=5, fig.width=7, echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 plot(x=tmp, type = "warp")
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -86,7 +90,7 @@ C_new <- cumsum(rnorm(10))
 C_update <- c(C0, C_new) 
 
 # result from incremental calculation
-res_inc <- IncDTW::idtw(Q = Q, C = C_update, newO = C_new, 
+res_inc <- IncDTW::idtw(Q = Q, C = C_update, newObs = C_new, 
                     gcm = tmp0$gcm, dm = tmp0$dm)
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -94,112 +98,6 @@ res_inc <- IncDTW::idtw(Q = Q, C = C_update, newO = C_new,
 res_scratch <- IncDTW::dtw(Q = Q, C = C_update) 
 sapply(names(res_inc), function(x){identical(res_inc[[x]], res_scratch[[x]])})
 
-## ---- message=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-WS <- 40
-my_check <- function(values) {
-  all(sapply(values[-1], function(x) identical(values[[1]], x)))
-}
-
-#--- define 'benchmark' functions from package: dtw
-dtw_0 <- function(C, Q){
-   dtw::dtw(C, Q, step.pattern = symmetric1, distance.only = TRUE)$distance }
-
-dtw_sc <- function(C, Q){
-   dtw::dtw(C, Q, step.pattern = symmetric1, 
-            window.type = "sakoechiba", distance.only = TRUE, window.size = WS)$distance }
-
-dtw_cm<- function(cm){
-   dtw::dtw(x=cm, step.pattern = symmetric1, distance.only = TRUE)$distance }
-
-#--- define functions to be tested from package: IncDTW
-idtw_dtw2vec <- function(C, Q){
-   IncDTW::dtw2vec(Q = Q, C = C) }
-
-idtw_dtw2vec_sc <- function(C, Q){
-   IncDTW::dtw2vec(Q = Q, C = C, ws = WS) }
-
-idtw_0 <- function(C, Q){
-   IncDTW::dtw(Q = Q, C = C)$distance }
-
-idtw_sc <- function(C, Q){
-   IncDTW::dtw(Q = Q, C = C, ws = WS)$distance }
-
-idtw_diff <- function(diffM){
-   IncDTW::dtw(Q = diffM, C = "diffM")$distane }
-
-idtw_cm <- function(cm){
-   IncDTW::dtw(Q = cm, C = "cm")$distance }
-
-idtw_inc <- function(C, Q, gcm00, dm00){
-   IncDTW::idtw(Q = Q, C = C, newO = C[(length(C)-9) : length(C)],
-                gcm = gcm00, dm = dm00)$distance }
-
-
-
-## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-tmp <- lapply(1:20, function(pseudoseed){
-   set.seed(pseudoseed)
-   C <- cumsum(rnorm(500))
-   Q <- cumsum(rnorm(480))
-   tmp00 <- IncDTW::dtw(Q = Q, C = C[1:(length(C)-10)], return_diffM = TRUE)
-   gcm00 <- tmp00$gcm
-   dm00 <- tmp00$dm
-   tmp <- IncDTW::dtw(Q = Q, C = C, return_diffM = TRUE)
-   diffM <- tmp$diffM
-   cm <- abs(diffM)
-   
-   
-   mic <- rbenchmark::benchmark( dtw_0(C, Q),
-                          dtw_cm(cm),
-                          #----
-                          idtw_dtw2vec(C, Q),
-                          idtw_0(C, Q),
-                          idtw_diff(diffM),
-                          idtw_cm(cm),
-                          idtw_inc(C, Q, gcm00, dm00),
-                          replications = benchmark_replications[1]
-                        )
-                          
-   return(as.data.frame(mic))
-})
-mics <- do.call(rbind, tmp)
-# class(mics) <- c("microbenchmark", "data.frame")
-
-## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-head(mics)
-tmp <- aggregate(mics$elapsed, by = list(mics$test), mean)
-tmp$xrel <- tmp$x/min(tmp$x)
-tmp
-
-## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-tmp <- lapply(1:20, function(pseudoseed){
-   set.seed(pseudoseed)
-   C <- cumsum(rnorm(500))
-   Q <- cumsum(rnorm(480))
-   tmp00 <- IncDTW::dtw(Q = Q, C = C[1:(length(C)-10)], return_diffM = TRUE)
-   gcm00 <- tmp00$gcm
-   dm00 <- tmp00$dm
-   tmp <- IncDTW::dtw(Q = Q, C = C, return_diffM = TRUE)
-   diffM <- tmp$diffM
-   cm <- abs(diffM)
-   
-   mic <- rbenchmark::benchmark( dtw_sc(C, Q),
-                          #----
-                          idtw_dtw2vec_sc(C,Q),
-                          idtw_sc(C, Q),
-                          replications = benchmark_replications[1])
-
-   return(as.data.frame(mic))
-})
-mics_sc <- do.call(rbind, tmp)
-
-## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-head(mics_sc)
-tmp <- aggregate(mics_sc$elapsed, by = list(mics_sc$test), mean)
-tmp$xrel <- tmp$x/min(tmp$x)
-tmp
-
-
 ## ---- message = FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 set.seed(1150)
 Q <- cos(1:100)
@@ -226,3 +124,66 @@ identical(result_decr1$jj, result_decr2$jj),
 identical(result_decr1$wp, result_decr2$wp))
 comparison_0
 
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+Q <- rnorm(100)
+C <- rnorm(120)
+IncDTW::dtw2vec(Q, C, ws = 30)$distance
+IncDTW::dtw(Q, C, ws = 30)$distance
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+set.seed(1210)
+Q <- cumsum(rnorm(800))
+C_initial <- Q[1:750] + rnorm(750)
+resV_init <- IncDTW::idtw2vec(Q = Q, newObs = C_initial, gcm_lc = NULL)
+
+C_newObs <- Q[751:800] + rnorm(50)
+resV_inc <- IncDTW::idtw2vec(Q = Q, newObs = C_newObs, 
+                             gcm_lc = resV_init$gcm_lc_new)
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+C_update <- c(C_initial, C_newObs)
+resV_scr <- IncDTW::dtw2vec(Q = Q, C = C_update)
+resV_scr$distance - resV_inc$distance
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+resV_init <- idtw2vec(Q = Q, newObs = C_initial, gcm_lc = NULL)
+resV_inc <-  idtw2vec(Q = Q, newObs = C_newObs, nC = length(C_initial),
+                      gcm_lc = resV_init$gcm_lc_new,
+                      gcm_lr = resV_init$gcm_lr_new)
+
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+Q_newObs <-cumsum(rnorm(10))
+resV_inc2 <- idtw2vec(Q = C_update, newObs = Q_newObs, nC = length(Q),
+                      gcm_lc = resV_inc$gcm_lr_new,
+                      gcm_lr = resV_inc$gcm_lc_new)
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+res_scratch <- dtw2vec(Q = c(Q, Q_newObs), C = c(C_initial, C_newObs))
+res_scratch$distance - resV_inc2$distance
+res_scratch$normalized_distance - resV_inc2$normalized_distance
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+Q <- sin(1:50)
+C <- cos(1:1000)
+tmp <- IncDTW::dtw(Q = Q, C = C)
+IncDTW::dtw_partial(tmp, partial_Q = FALSE, partial_C = TRUE)
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+Q <- sin(1:100)
+C <- c(rnorm(50), Q)
+tmp <- IncDTW::dtw(Q = rev(Q), C = rev(C))
+dtw_partial(tmp, partial_Q = FALSE, partial_C = TRUE, reverse = TRUE)
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+Q <- sin(seq(1, 50, length.out = 200))
+C <- cos(seq(1, 5, length.out = 20))
+tmpi <- idtw2vec(Q = Q, newObs = C)
+dtw_partial(tmpi, partial_Q = TRUE, partial_C = FALSE)
+
+## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+C_new <- cos(seq(5, 10, length.out = 20))
+tmp1 <- idtw2vec(Q = Q, newObs = C_new, gcm_lc = tmpi$gcm_lc_new, 
+                 gcm_lr = tmpi$gcm_lr_new, nC = length(C))
+dtw_partial(tmp1, partial_Q = TRUE, partial_C = FALSE)
+
