@@ -32,14 +32,17 @@ extern SEXP _IncDTW_cpp_get_tube(SEXP, SEXP);
 extern SEXP _IncDTW_cpp_kNN_rev(SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_cpp_local_min(SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_cpp_norm01(SEXP, SEXP, SEXP);
-extern SEXP _IncDTW_cpp_rundtw(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _IncDTW_cpp_rundtw_mv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _IncDTW_cpp_rundtw(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _IncDTW_cpp_rundtw_mv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _IncDTW_cpp_rundtw_znorm(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _IncDTW_cpp_rundtw_znorm_mv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_cpp_set_tube(SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_cpp_set_tube_mv(SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_cpp_znorm(SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_GCM_cpp(SEXP, SEXP);
 extern SEXP _IncDTW_GCM_Sakoe_cpp(SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_get_lb(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _IncDTW_get_lb_znorm(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_IGCM_cpp(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_IGCM_Sakoe_cpp(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _IncDTW_normmat(SEXP);
@@ -73,14 +76,17 @@ static const R_CallMethodDef CallEntries[] = {
     {"_IncDTW_cpp_kNN_rev",           (DL_FUNC) &_IncDTW_cpp_kNN_rev,            3},
     {"_IncDTW_cpp_local_min",         (DL_FUNC) &_IncDTW_cpp_local_min,          3},
     {"_IncDTW_cpp_norm01",            (DL_FUNC) &_IncDTW_cpp_norm01,             3},
-    {"_IncDTW_cpp_rundtw",            (DL_FUNC) &_IncDTW_cpp_rundtw,            11},
-    {"_IncDTW_cpp_rundtw_mv",         (DL_FUNC) &_IncDTW_cpp_rundtw_mv,         12},
+    {"_IncDTW_cpp_rundtw",            (DL_FUNC) &_IncDTW_cpp_rundtw,            12},
+    {"_IncDTW_cpp_rundtw_mv",         (DL_FUNC) &_IncDTW_cpp_rundtw_mv,         13},
+    {"_IncDTW_cpp_rundtw_znorm",      (DL_FUNC) &_IncDTW_cpp_rundtw_znorm,      11},
+    {"_IncDTW_cpp_rundtw_znorm_mv",   (DL_FUNC) &_IncDTW_cpp_rundtw_znorm_mv,   12},
     {"_IncDTW_cpp_set_tube",          (DL_FUNC) &_IncDTW_cpp_set_tube,           3},
     {"_IncDTW_cpp_set_tube_mv",       (DL_FUNC) &_IncDTW_cpp_set_tube_mv,        3},
     {"_IncDTW_cpp_znorm",             (DL_FUNC) &_IncDTW_cpp_znorm,              3},
     {"_IncDTW_GCM_cpp",               (DL_FUNC) &_IncDTW_GCM_cpp,                2},
     {"_IncDTW_GCM_Sakoe_cpp",         (DL_FUNC) &_IncDTW_GCM_Sakoe_cpp,          3},
     {"_IncDTW_get_lb",                (DL_FUNC) &_IncDTW_get_lb,                 4},
+    {"_IncDTW_get_lb_znorm",          (DL_FUNC) &_IncDTW_get_lb_znorm,           7},
     {"_IncDTW_IGCM_cpp",              (DL_FUNC) &_IncDTW_IGCM_cpp,               4},
     {"_IncDTW_IGCM_Sakoe_cpp",        (DL_FUNC) &_IncDTW_IGCM_Sakoe_cpp,         5},
     {"_IncDTW_normmat",               (DL_FUNC) &_IncDTW_normmat,                1},
